//+------------------------------------------------------------------+
//|                                                  WPR TEST MA.mq5 |
//|                                                Ronnie Mansolillo |
//|                        http://rmansolillo.wix.com/rosimantrading |
//+------------------------------------------------------------------+
#property copyright "Ronnie Mansolillo"
#property link      "http://rmansolillo.wix.com/rosimantrading"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalMA.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingWPRwStops.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedMargin.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title                       ="WPR TEST MA";  // Document name
ulong                    Expert_MagicNumber                 =31164;          // 
bool                     Expert_EveryTick                   =false;          // 
//--- inputs for main signal
input int                Signal_ThresholdOpen               =20;             // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose              =20;             // Signal threshold value to close [0...100]
input double             Signal_PriceLevel                  =0.0;            // Price level to execute a deal
input double             Signal_StopLevel                   =0.0;           // Stop Loss level (in points)
input double             Signal_TakeLevel                   =0.0;           // Take Profit level (in points)
input int                Signal_Expiration                  =0;              // Expiration of pending orders (in bars)
input int                Signal_MA_PeriodMA                 =50;             // Moving Average(50,0,...) Period of averaging
input int                Signal_MA_Shift                    =0;              // Moving Average(50,0,...) Time shift
input ENUM_MA_METHOD     Signal_MA_Method                   =MODE_SMA;       // Moving Average(50,0,...) Method of averaging
input ENUM_APPLIED_PRICE Signal_MA_Applied                  =PRICE_CLOSE;    // Moving Average(50,0,...) Prices series
input double             Signal_MA_Weight                   =1.0;            // Moving Average(50,0,...) Weight [0...1.0]
//--- inputs for trailing
input ENUM_TIMEFRAMES    Trailing_WPR_Trailing_TimeframeWPR =PERIOD_CURRENT; // Timeframe of WPR
input int                Trailing_WPR_Trailing_PeriodWPR    =5;              // Period of WPR
input int                Trailing_WPR_Trailing_StopLevelsWPR=30;             // Stop levels of WPR-trailing (-50StpLvl)
input int                Trailing_WPR_Trailing_ShortStop    =250;             // Short stop
input int                Trailing_WPR_Trailing_LongStop     =2500;           // Long stop
//--- inputs for money
input double             Money_FixMargin_Percent            =1.0;            // Percentage of margin
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalMA
CSignalMA *filter0=new CSignalMA;
if(filter0==NULL)
  {
   //--- failed
   printf(__FUNCTION__+": error creating filter0");
   ExtExpert.Deinit();
   return(INIT_FAILED);
  }
signal.AddFilter(filter0);
//--- Set filter parameters
filter0.PeriodMA(Signal_MA_PeriodMA);
filter0.Shift(Signal_MA_Shift);
filter0.Method(Signal_MA_Method);
filter0.Applied(Signal_MA_Applied);
filter0.Weight(Signal_MA_Weight);
//--- Creation of trailing object
  CTrailingWPRLongShortStps *trailing=new CTrailingWPRLongShortStps;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set trailing parameters
trailing.TimeframeWPR(Trailing_WPR_Trailing_TimeframeWPR);
trailing.PeriodWPR(Trailing_WPR_Trailing_PeriodWPR);
trailing.StopLevelsWPR(Trailing_WPR_Trailing_StopLevelsWPR);
trailing.ShortStop(Trailing_WPR_Trailing_ShortStop);
trailing.LongStop(Trailing_WPR_Trailing_LongStop);
//--- Creation of money object
CMoneyFixedMargin *money=new CMoneyFixedMargin;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set money parameters
money.Percent(Money_FixMargin_Percent);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
     {
      //--- failed
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- ok
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   ExtExpert.OnTick();
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert.OnTimer();
  }
//+------------------------------------------------------------------+
